@@ -1,4 +1,4 @@
-## Copyright (C) 2010   Lukas F. Reichlin
+## Copyright (C) 2009-2015   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -28,7 +28,7 @@ function [retsys, retlti] = __sys2frd__ (sys, w = [])
     w = __frequency_vector__ (sys);
   endif
 
-  H = __freqresp__ (sys, w);
+  H = freqresp (sys, w);
 
   retsys = frd (H, w);  # tsam is set below
   retlti = sys.lti;     # preserve lti properties
